==> myfaces-core-assembly-2.1.18-src.tar.gz: myfaces-core-module-2.1.18/impl/src/main/java/org/apache/myfaces/view/facelets/compiler/NamespaceUnit.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.compiler;

import java.util.HashMap;
import java.util.Map;

import javax.faces.view.facelets.FaceletHandler;

import org.apache.myfaces.view.facelets.tag.TagLibrary;

/**
 * 
 * @author Jacob Hookom
 * @version $Id: NamespaceUnit.java 1187701 2011-10-22 12:21:54Z bommel $
 */
final class NamespaceUnit extends CompilationUnit
{

    private final Map<String, String> ns = new HashMap<String, String>();
    private final TagLibrary library;

    public NamespaceUnit(TagLibrary library)
    {
        this.library = library;
    }

    public FaceletHandler createFaceletHandler()
    {
        FaceletHandler next = this.getNextFaceletHandler();
        return new NamespaceHandler(next, this.library, this.ns);
    }

    public void setNamespace(String prefix, String uri)
    {
        this.ns.put(prefix, uri);
    }

}

==> myfaces-core-assembly-3.0.3-src.tar.gz: myfaces-core-module-3.0.3/impl/src/main/java/org/apache/myfaces/view/facelets/compiler/NamespaceUnit.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.compiler;

import java.util.HashMap;
import java.util.Map;

import jakarta.faces.view.facelets.FaceletHandler;

import org.apache.myfaces.view.facelets.tag.TagLibrary;

/**
 * 
 * @author Jacob Hookom
 * @version $Id$
 */
final class NamespaceUnit extends CompilationUnit
{

    private final Map<String, String> ns = new HashMap<String, String>();
    private final TagLibrary library;

    public NamespaceUnit(TagLibrary library)
    {
        this.library = library;
    }

    public FaceletHandler createFaceletHandler()
    {
        FaceletHandler next = this.getNextFaceletHandler();
        return new NamespaceHandler(next, this.library, this.ns);
    }

    public void setNamespace(String prefix, String uri)
    {
        this.ns.put(prefix, uri);
    }

}
